sample_annn_pkg_001

# Load modules¶

In [1]:

    import sample_annn_pkg as sap

# Samples¶

## sample001¶

In [2]:

    sap.func02()

    success!!
    poyo

## sample002¶

In [3]:

    # load csv
    df0 = sap.datasets.load_sample_data0()
    df0

    load sample data0
    file format: csv
    sample pandas.DataFrame:
       col1  col2  col3
    0     1     2     3
    1     4     5     6
    2     7     8     9

Out[3]:

| col1 | col2 | col3
--- | --- | --- | ---
0 | 1 | 2 | 3
1 | 4 | 5 | 6
2 | 7 | 8 | 9

## sample003¶

In [4]:

    # load excel
    df1 = sap.datasets.load_sample_data1()
    df1

    load sample data1
    file format: excel
    sample pandas.DataFrame:
       col4  col5  col6
    0  hoge    10    11
    1  fuga    12    13
    2  poyo    14    15
    3  piyo    16    17

Out[4]:

| col4 | col5 | col6
--- | --- | --- | ---
0 | hoge | 10 | 11
1 | fuga | 12 | 13
2 | poyo | 14 | 15
3 | piyo | 16 | 17